==> findbugs-maven-plugin-2.0.1-sources.jar: org/codehaus/mojo/findbugs/FindbugsViolationCheckMojo.java <==
//
// Generated stub from file:/C:/svnWork/findbugs-maven-plugin/target/checkout/src/main/groovy/org/codehaus/mojo/findbugs/FindbugsViolationCheckMojo.groovy
//

package org.codehaus.mojo.findbugs;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import edu.umd.cs.findbugs.DetectorFactory;
import edu.umd.cs.findbugs.DetectorFactoryCollection;
import edu.umd.cs.findbugs.FindBugs2;
import edu.umd.cs.findbugs.Project;
import edu.umd.cs.findbugs.TextUIBugReporter;
import edu.umd.cs.findbugs.XMLBugReporter;
import edu.umd.cs.findbugs.config.UserPreferences;
import edu.umd.cs.findbugs.filter.FilterException;
import org.apache.maven.artifact.DependencyResolutionRequiredException;
import org.apache.maven.artifact.resolver.ArtifactNotFoundException;
import org.apache.maven.artifact.resolver.ArtifactResolutionException;
import org.apache.maven.project.MavenProject;
import org.codehaus.groovy.maven.mojo.GroovyMojo;
import org.codehaus.plexus.resource.ResourceManager;
import org.codehaus.plexus.resource.loader.FileResourceLoader;
import org.codehaus.plexus.util.FileUtils;

/**
 * Fail the build if there were any FindBugs violations in the source code.
 * An XML report is put out by default in the target directory with the errors.
 * To see more documentation about FindBugs' options, please see the
 * <a href="http://findbugs.sourceforge.net/manual/index.html">FindBugs Manual.</a>
 *
 * @since 2.0
 * @goal check
 * @phase verify
 * @requiresDependencyResolution compile
 * @requiresProject
 * @author <a href="mailto:gleclaire@codehaus.org">Garvin LeClaire</a>
 * @version $Id: FindbugsViolationCheckMojo.groovy gleclaire $
 */
public class FindbugsViolationCheckMojo
    extends GroovyMojo
{
    /**
     * The name of the property resource bundle (Filesystem).
     */
    static final private java.lang.String BUNDLE_NAME = null;
    static final public java.lang.String getBUNDLE_NAME() {
        throw new InternalError("Stubbed method");
    }

    /**
     * The name of the coreplugin.
     */
    static final private java.lang.String FINDBUGS_COREPLUGIN = null;
    static final public java.lang.String getFINDBUGS_COREPLUGIN() {
        throw new InternalError("Stubbed method");
    }

    /**
     * The regex pattern to search for java class files.
     */
    static final private java.lang.String JAVA_REGEX_PATTERN = null;
    static final public java.lang.String getJAVA_REGEX_PATTERN() {
        throw new InternalError("Stubbed method");
    }

    /**
     * Directory containing the class files for FindBugs to analyze.
     *
     * @parameter default-value="${project.build.outputDirectory}"
     * @required
     */
    private File classFilesDirectory = null;
    public File getClassFilesDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setClassFilesDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * turn on Findbugs debugging
     *
     * @parameter default-value="false"
     */
    private Boolean debug = null;
    public Boolean getDebug() {
        throw new InternalError("Stubbed method");
    }
    public void setDebug(Boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The visitor list to run. This is a comma-delimited list.
     *
     * @parameter
     */
    private java.lang.String visitors = null;
    public java.lang.String getVisitors() {
        throw new InternalError("Stubbed method");
    }
    public void setVisitors(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The visitor list to omit. This is a comma-delimited list.
     *
     * @parameter
     */
    private java.lang.String omitVisitors = null;
    public java.lang.String getOmitVisitors() {
        throw new InternalError("Stubbed method");
    }
    public void setOmitVisitors(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * List of artifacts this plugin depends on. Used for resolving the Findbugs coreplugin.
     *
     * @parameter expression="${plugin.artifacts}"
     * @required
     * @readonly
     */
    private ArrayList pluginArtifacts = null;
    public ArrayList getPluginArtifacts() {
        throw new InternalError("Stubbed method");
    }
    public void setPluginArtifacts(ArrayList value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Effort of the bug finders. Valid values are Min, Default and Max.
     *
     * @parameter default-value="Default"
     */
    private java.lang.String effort = null;
    public java.lang.String getEffort() {
        throw new InternalError("Stubbed method");
    }
    public void setEffort(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Specifies the directory where the findbugs xml output will be generated.
     *
     * @parameter default-value="${project.build.directory}"
     * @required
     */
    private File findbugsCheckOutputDirectory = null;
    public File getFindbugsCheckOutputDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setFindbugsCheckOutputDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Restrict analysis to the given comma-separated list of classes and packages.
     *
     * @parameter
     */
    private java.lang.String onlyAnalyze = null;
    public java.lang.String getOnlyAnalyze() {
        throw new InternalError("Stubbed method");
    }
    public void setOnlyAnalyze(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The plugin list to include in the report. This is a comma-delimited list.
     *
     * @parameter
     */
    private java.lang.String pluginList = null;
    public java.lang.String getPluginList() {
        throw new InternalError("Stubbed method");
    }
    public void setPluginList(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The Flag letting us know if classes have been loaded already.
     *
     * @parameter
     * @readonly
     */
    static private boolean pluginLoaded = false;
    static public boolean getPluginLoaded() {
        throw new InternalError("Stubbed method");
    }
    static public boolean isPluginLoaded() {
        throw new InternalError("Stubbed method");
    }
    static public void setPluginLoaded(boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Maven Project
     *
     * @parameter expression="${project}"
     * @required
     * @readonly
     */
    private MavenProject project = null;
    public MavenProject getProject() {
        throw new InternalError("Stubbed method");
    }
    public void setProject(MavenProject value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Relaxed reporting mode. For many detectors, this option suppresses the heuristics used to avoid reporting false
     * positives.
     *
     * @parameter default-value="false"
     */
    private Boolean relaxed = null;
    public Boolean getRelaxed() {
        throw new InternalError("Stubbed method");
    }
    public void setRelaxed(Boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Skip entire check.
     *
     * @parameter expression="${skip}" default-value="false"
     */
    private boolean skip = false;
    public boolean getSkip() {
        throw new InternalError("Stubbed method");
    }
    public boolean isSkip() {
        throw new InternalError("Stubbed method");
    }
    public void setSkip(boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Fail the build on an error.
     *
     * @parameter default-value="true"
     * @since 2.0
     */
    private boolean failOnError = false;
    public boolean getFailOnError() {
        throw new InternalError("Stubbed method");
    }
    public boolean isFailOnError() {
        throw new InternalError("Stubbed method");
    }
    public void setFailOnError(boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Threshold of minimum bug severity to report. Valid values are High, Default, Low, Ignore, and Exp (for experimental).
     *
     * @parameter default-value="Default"
     */
    private java.lang.String threshold = null;
    public java.lang.String getThreshold() {
        throw new InternalError("Stubbed method");
    }
    public void setThreshold(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * File name of the include filter. Only bugs in matching the filters are reported.
     *
     * @parameter
     */
    private java.lang.String includeFilterFile = null;
    public java.lang.String getIncludeFilterFile() {
        throw new InternalError("Stubbed method");
    }
    public void setIncludeFilterFile(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * File name of the exclude filter. Bugs matching the filters are not reported.
     *
     * @parameter
     */
    private java.lang.String excludeFilterFile = null;
    public java.lang.String getExcludeFilterFile() {
        throw new InternalError("Stubbed method");
    }
    public void setExcludeFilterFile(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Resource bundle for a specific locale.
     *
     * @parameter
     * @readonly
     */
    private ResourceBundle bundle = null;
    public ResourceBundle getBundle() {
        throw new InternalError("Stubbed method");
    }
    public void setBundle(ResourceBundle value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * @component
     * @required
     * @readonly
     */
    private ResourceManager resourceManager = null;
    public ResourceManager getResourceManager() {
        throw new InternalError("Stubbed method");
    }
    public void setResourceManager(ResourceManager value) {
        throw new InternalError("Stubbed method");
    }

    public void execute() {
        throw new InternalError("Stubbed method");
    }

    /**
     * Returns the effort parameter to use.
     *
     * @return A valid effort parameter.
     */
    protected EffortParameter getEffortParameter() {
        throw new InternalError("Stubbed method");
    }

    /**
     * Adds the dependend libraries of the project to the findbugs aux classpath.
     *
     * @param findBugsProject
The find bugs project to add the aux classpath entries.
     */
    protected void addClasspathEntriesToFindBugsProject(Project findBugsProject) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Adds the specified plugins to findbugs. The coreplugin is always added first.
     */
    protected void addPluginsToFindBugs() {
        throw new InternalError("Stubbed method");
    }

    /**
     * Returns the threshold parameter to use.
     *
     * @return A valid threshold parameter.
     */
    protected ThresholdParameter getThresholdParameter() {
        throw new InternalError("Stubbed method");
    }

    /**
     * Adds the specified visitors to findbugs.
     *
     * @param preferences
The find bugs UserPreferences.
     */
    protected void addVisitorsToFindBugs(UserPreferences preferences) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Sets the Debug Level
     *
     * @param findBugs
The find bugs to add debug level information.
     */
    protected void setFindBugsDebug(FindBugs2 findBugs) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Adds the specified filters of the project to the findbugs.
     *
     * @param findBugs
The find bugs to add the filters.
     */
    protected void addFiltersToFindBugs(FindBugs2 findBugs) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Adds the specified plugins to findbugs. The coreplugin is always added first.
     */
    protected void addClassScreenerToFindBugs(FindBugs2 findBugs) {
        throw new InternalError("Stubbed method");
    }

    public groovy.lang.MetaClass getMetaClass() {
        throw new InternalError("Stubbed method");
    }

    public void setMetaClass(groovy.lang.MetaClass metaClass) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object invokeMethod(java.lang.String name, java.lang.Object args) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getProperty(java.lang.String name) {
        throw new InternalError("Stubbed method");
    }

    public void setProperty(java.lang.String name, java.lang.Object value) {
        throw new InternalError("Stubbed method");
    }
}

==> findbugs-maven-plugin-2.2-sources.jar: org/codehaus/mojo/findbugs/FindbugsViolationCheckMojo.java <==
//
// Generated stub from file:/C:/svnWork/findbugs-maven-plugin/target/checkout/src/main/groovy/org/codehaus/mojo/findbugs/FindbugsViolationCheckMojo.groovy
//

package org.codehaus.mojo.findbugs;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import org.apache.maven.artifact.repository.DefaultArtifactRepository;
import org.apache.maven.artifact.resolver.ArtifactResolver;
import org.codehaus.doxia.site.renderer.SiteRenderer;
import org.apache.maven.doxia.tools.SiteTool;
import org.apache.maven.project.MavenProject;
import org.codehaus.groovy.maven.mojo.GroovyMojo;
import org.codehaus.plexus.resource.ResourceManager;
import org.codehaus.plexus.util.FileUtils;

/**
 * Fail the build if there were any FindBugs violations in the source code.
 * An XML report is put out by default in the target directory with the errors.
 * To see more documentation about FindBugs' options, please see the
 * <a href="http://findbugs.sourceforge.net/manual/index.html">FindBugs Manual.</a>
 *
 * @since 2.0
 * @goal check
 * @phase verify
 * @execute goal="findbugs"
 * @requiresDependencyResolution compile
 * @requiresProject
 * @author <a href="mailto:gleclaire@codehaus.org">Garvin LeClaire</a>
 * @version $Id: FindbugsViolationCheckMojo.groovy gleclaire $
 */
public class FindbugsViolationCheckMojo
    extends GroovyMojo
    implements FindBugsInfo
{
    /**
     * Location where generated html will be created.
     *
     * @parameter default-value="${project.reporting.outputDirectory}"
     * @required
     */
    private File outputDirectory = null;
    public File getOutputDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setOutputDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Turn on and off xml output of the Findbugs report.
     *
     * @parameter default-value="false"
     * @since 1.0.0
     */
    private boolean xmlOutput = false;
    public boolean getXmlOutput() {
        throw new InternalError("Stubbed method");
    }
    public boolean isXmlOutput() {
        throw new InternalError("Stubbed method");
    }
    public void setXmlOutput(boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Specifies the directory where the xml output will be generated.
     *
     * @parameter default-value="${project.build.directory}"
     * @required
     * @since 1.0.0
     */
    private File xmlOutputDirectory = null;
    public File getXmlOutputDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setXmlOutputDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Turn on and off findbugs native xml output of the Findbugs report.
     *
     * @parameter default-value="false"
     * @since 1.2.0
     * @deprecated
     */
    private boolean findbugsXmlOutput = false;
    public boolean getFindbugsXmlOutput() {
        throw new InternalError("Stubbed method");
    }
    public boolean isFindbugsXmlOutput() {
        throw new InternalError("Stubbed method");
    }
    public void setFindbugsXmlOutput(boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Specifies the directory where the findbugs native xml output will be generated.
     *
     * @parameter default-value="${project.build.directory}"
     * @required
     * @since 1.2.0
     */
    private File findbugsXmlOutputDirectory = null;
    public File getFindbugsXmlOutputDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setFindbugsXmlOutputDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Doxia Site Renderer.
     *
     * @parameter expression="${component.org.codehaus.doxia.site.renderer.SiteRenderer}"
     * @required
     * @readonly
     */
    private SiteRenderer siteRenderer = null;
    public SiteRenderer getSiteRenderer() {
        throw new InternalError("Stubbed method");
    }
    public void setSiteRenderer(SiteRenderer value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Directory containing the class files for FindBugs to analyze.
     *
     * @parameter default-value="${project.build.outputDirectory}"
     * @required
     */
    private File classFilesDirectory = null;
    public File getClassFilesDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setClassFilesDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Directory containing the test class files for FindBugs to analyze.
     *
     * @parameter default-value="${project.build.testOutputDirectory}"
     * @required
     */
    private File testClassFilesDirectory = null;
    public File getTestClassFilesDirectory() {
        throw new InternalError("Stubbed method");
    }
    public void setTestClassFilesDirectory(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Location of the Xrefs to link to.
     *
     * @parameter default-value="${project.reporting.outputDirectory}/xref"
     */
    private File xrefLocation = null;
    public File getXrefLocation() {
        throw new InternalError("Stubbed method");
    }
    public void setXrefLocation(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Location of the Test Xrefs to link to.
     *
     * @parameter default-value="${project.reporting.outputDirectory}/xref-test"
     */
    private File xrefTestLocation = null;
    public File getXrefTestLocation() {
        throw new InternalError("Stubbed method");
    }
    public void setXrefTestLocation(File value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The directories containing the sources to be compiled.
     *
     * @parameter expression="${project.compileSourceRoots}"
     * @required
     * @readonly
     */
    private List compileSourceRoots = null;
    public List getCompileSourceRoots() {
        throw new InternalError("Stubbed method");
    }
    public void setCompileSourceRoots(List value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The directories containing the test-sources to be compiled.
     *
     * @parameter expression="${project.testCompileSourceRoots}"
     * @required
     * @readonly
     * @since 2.0
     */
    private List testSourceRoots = null;
    public List getTestSourceRoots() {
        throw new InternalError("Stubbed method");
    }
    public void setTestSourceRoots(List value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Run Findbugs on the tests.
     *
     * @parameter default-value="false"
     * @since 2.0
     */
    private boolean includeTests = false;
    public boolean getIncludeTests() {
        throw new InternalError("Stubbed method");
    }
    public boolean isIncludeTests() {
        throw new InternalError("Stubbed method");
    }
    public void setIncludeTests(boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * List of artifacts this plugin depends on. Used for resolving the Findbugs coreplugin.
     *
     * @parameter expression="${plugin.artifacts}"
     * @required
     * @readonly
     */
    private ArrayList pluginArtifacts = null;
    public ArrayList getPluginArtifacts() {
        throw new InternalError("Stubbed method");
    }
    public void setPluginArtifacts(ArrayList value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The local repository, needed to download the coreplugin jar.
     *
     * @parameter expression="${localRepository}"
     * @required
     * @readonly
     */
    private DefaultArtifactRepository localRepository = null;
    public DefaultArtifactRepository getLocalRepository() {
        throw new InternalError("Stubbed method");
    }
    public void setLocalRepository(DefaultArtifactRepository value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Remote repositories which will be searched for the coreplugin jar.
     *
     * @parameter expression="${project.remoteArtifactRepositories}"
     * @required
     * @readonly
     */
    private List remoteArtifactRepositories = null;
    public List getRemoteArtifactRepositories() {
        throw new InternalError("Stubbed method");
    }
    public void setRemoteArtifactRepositories(List value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Maven Project
     *
     * @parameter expression="${project}"
     * @required
     * @readonly
     */
    private MavenProject project = null;
    public MavenProject getProject() {
        throw new InternalError("Stubbed method");
    }
    public void setProject(MavenProject value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Encoding used for xml files. Default value is UTF-8.
     *
     * @parameter default-value="UTF-8"
     * @readonly
     */
    private java.lang.String xmlEncoding = null;
    public java.lang.String getXmlEncoding() {
        throw new InternalError("Stubbed method");
    }
    public void setXmlEncoding(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The file encoding to use when reading the source files. If the property <code>project.build.sourceEncoding</code>
     * is not set, the platform default encoding is used.
     *
     * @parameter expression="${encoding}" default-value="${project.build.sourceEncoding}"
     * @since 2.2
     */
    private java.lang.String sourceEncoding = null;
    public java.lang.String getSourceEncoding() {
        throw new InternalError("Stubbed method");
    }
    public void setSourceEncoding(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The file encoding to use when creating the HTML reports. If the property <code>project.reporting.outputEncoding</code>
     * is not set, the platform default encoding is used.
     *
     * @parameter expression="${outputEncoding}" default-value="${project.reporting.outputEncoding}"
     * @since 2.2
     */
    private java.lang.String outputEncoding = null;
    public java.lang.String getOutputEncoding() {
        throw new InternalError("Stubbed method");
    }
    public void setOutputEncoding(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Threshold of minimum bug severity to report. Valid values are High, Default, Low, Ignore, and Exp (for experimental).
     *
     * @parameter
     */
    private java.lang.String threshold = null;
    public java.lang.String getThreshold() {
        throw new InternalError("Stubbed method");
    }
    public void setThreshold(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Artifact resolver, needed to download the coreplugin jar.
     *
     * @component role="org.apache.maven.artifact.resolver.ArtifactResolver"
     * @required
     * @readonly
     */
    private ArtifactResolver artifactResolver = null;
    public ArtifactResolver getArtifactResolver() {
        throw new InternalError("Stubbed method");
    }
    public void setArtifactResolver(ArtifactResolver value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * File name of the include filter. Only bugs in matching the filters are reported.
     *
     * @parameter
     * @since 1.0-beta-1
     */
    private java.lang.String includeFilterFile = null;
    public java.lang.String getIncludeFilterFile() {
        throw new InternalError("Stubbed method");
    }
    public void setIncludeFilterFile(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * File name of the exclude filter. Bugs matching the filters are not reported.
     *
     * @parameter
     * @since 1.0-beta-1
     */
    private java.lang.String excludeFilterFile = null;
    public java.lang.String getExcludeFilterFile() {
        throw new InternalError("Stubbed method");
    }
    public void setExcludeFilterFile(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Effort of the bug finders. Valid values are Min, Default and Max.
     *
     * @parameter
     * @since 1.0-beta-1
     */
    private java.lang.String effort = null;
    public java.lang.String getEffort() {
        throw new InternalError("Stubbed method");
    }
    public void setEffort(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * turn on Findbugs debugging
     *
     * @parameter default-value="false"
     */
    private Boolean debug = null;
    public Boolean getDebug() {
        throw new InternalError("Stubbed method");
    }
    public void setDebug(Boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Relaxed reporting mode. For many detectors, this option suppresses the heuristics used to avoid reporting false
     * positives.
     *
     * @parameter default-value="false"
     * @since 1.1
     */
    private Boolean relaxed = null;
    public Boolean getRelaxed() {
        throw new InternalError("Stubbed method");
    }
    public void setRelaxed(Boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The visitor list to run. This is a comma-delimited list.
     *
     * @parameter
     * @since 1.0-beta-1
     */
    private java.lang.String visitors = null;
    public java.lang.String getVisitors() {
        throw new InternalError("Stubbed method");
    }
    public void setVisitors(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The visitor list to omit. This is a comma-delimited list.
     *
     * @parameter
     * @since 1.0-beta-1
     */
    private java.lang.String omitVisitors = null;
    public java.lang.String getOmitVisitors() {
        throw new InternalError("Stubbed method");
    }
    public void setOmitVisitors(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * The plugin list to include in the report. This is a comma-delimited list.
     *
     * @parameter
     * @since 1.0-beta-1
     */
    private java.lang.String pluginList = null;
    public java.lang.String getPluginList() {
        throw new InternalError("Stubbed method");
    }
    public void setPluginList(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Restrict analysis to the given comma-separated list of classes and packages.
     *
     * @parameter
     * @since 1.1
     */
    private java.lang.String onlyAnalyze = null;
    public java.lang.String getOnlyAnalyze() {
        throw new InternalError("Stubbed method");
    }
    public void setOnlyAnalyze(java.lang.String value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Skip entire check.
     *
     * @parameter expression="${findbugs.skip}" default-value="false"
     * @since 1.1
     */
    private boolean skip = false;
    public boolean getSkip() {
        throw new InternalError("Stubbed method");
    }
    public boolean isSkip() {
        throw new InternalError("Stubbed method");
    }
    public void setSkip(boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * @component
     * @required
     * @readonly
     * @since 2.0
     */
    private ResourceManager resourceManager = null;
    public ResourceManager getResourceManager() {
        throw new InternalError("Stubbed method");
    }
    public void setResourceManager(ResourceManager value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * SiteTool.
     *
     * @since 2.1-SNAPSHOT
     * @component role="org.apache.maven.doxia.tools.SiteTool"
     * @required
     * @readonly
     */
    protected SiteTool siteTool = null;

    /**
     * Fail the build on an error.
     *
     * @parameter default-value="true"
     * @since 2.0
     */
    private boolean failOnError = false;
    public boolean getFailOnError() {
        throw new InternalError("Stubbed method");
    }
    public boolean isFailOnError() {
        throw new InternalError("Stubbed method");
    }
    public void setFailOnError(boolean value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Maximum Java heap size in megabytes (default=512).
     *
     * @parameter default-value="512"
     * @since 2.2
     */
    private int maxHeap = 0;
    public int getMaxHeap() {
        throw new InternalError("Stubbed method");
    }
    public void setMaxHeap(int value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Specifies the amount of time, in milliseconds, that FindBugs may run before
     * it is assumed to be hung and is terminated.
     * The default is 600,000 milliseconds, which is ten minutes.
     *
     * @parameter default-value="600000"
     * @since 2.2
     */
    private int timeout = 0;
    public int getTimeout() {
        throw new InternalError("Stubbed method");
    }
    public void setTimeout(int value) {
        throw new InternalError("Stubbed method");
    }

    private int bugCount = 0;
    public int getBugCount() {
        throw new InternalError("Stubbed method");
    }
    public void setBugCount(int value) {
        throw new InternalError("Stubbed method");
    }

    private int errorCount = 0;
    public int getErrorCount() {
        throw new InternalError("Stubbed method");
    }
    public void setErrorCount(int value) {
        throw new InternalError("Stubbed method");
    }

    public void execute() {
        throw new InternalError("Stubbed method");
    }

    public groovy.lang.MetaClass getMetaClass() {
        throw new InternalError("Stubbed method");
    }

    public void setMetaClass(groovy.lang.MetaClass metaClass) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object invokeMethod(java.lang.String name, java.lang.Object args) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getProperty(java.lang.String name) {
        throw new InternalError("Stubbed method");
    }

    public void setProperty(java.lang.String name, java.lang.Object value) {
        throw new InternalError("Stubbed method");
    }
}
